@@ -183,7 +183,7 @@ the I18NOBJECT.
 sub translate {
 	my ($self, $i18n) = @_;
 	my ($root, @text_elts, $i18n_ret, $parent_gi, $parent_i18n,
-	    %parents);
+	    %parents, $text, $ws_before, $ws_after);
 
 	$root = $self->root();
 
@@ -192,15 +192,37 @@ sub translate {
 	for my $elt (@text_elts) {
 		$parent_gi = $elt->parent->gi();
 
-		next if $parent_gi eq 'style';
-
+		next if $parent_gi eq 'style'
+            || $parent_gi eq 'script';
+        
 		$parent_i18n = $elt->parent->att('i18n-key');
 		
 		if ($parent_i18n) {
 			$i18n_ret = $i18n->localize($parent_i18n);
 		}
 		else {
-			$i18n_ret = $i18n->localize($elt->text());
+            $text = $elt->text;
+
+            # remove surrounding whitespace before passing
+            # to translation function
+            if ($text =~ s/^(\s+)//s) {
+                $ws_before = $1;
+            }
+            else {
+                $ws_before = '';
+            }
+
+            if ($text =~ s/(\s+)$//s) {
+                $ws_after = $1;
+            }
+            else {
+                $ws_after = '';
+            }
+
+            # skip empty text
+            next unless $text;
+            
+			$i18n_ret = $ws_before . $i18n->localize($text) . $ws_after;
 		}
 
 		$elt->set_text($i18n_ret);
